summaryrefslogtreecommitdiff
path: root/include/system.h
diff options
context:
space:
mode:
authorDaisuke Nojiri <dnojiri@chromium.org>2017-11-30 17:58:38 -0800
committerchrome-bot <chrome-bot@chromium.org>2017-12-05 18:00:38 -0800
commit23149261dc4a9429a1c98aa829e02d4a3ec5103a (patch)
treee86a656759c50faba656be820118ef25fb7a3010 /include/system.h
parent0a5e908467b5f5169a7197bbe7b327e06432d4cf (diff)
downloadchrome-ec-23149261dc4a9429a1c98aa829e02d4a3ec5103a.tar.gz
system: Allow hibernate to clear AP_OFF flag
After firmware update, cr50 toggles the EC's reset line, expecting the system will boot. This isn't the case for Chromebox because it sets AP_OFF flag on a clean shutdown (to restore the previous power state after power loss & restore). This patch adds EC_REBOOT_HIBERNATE_CLEAR_AP_OFF to EC reboot command. It makes EC first clear AP_OFF then hibernate. BUG=b:69721737 BRANCH=none TEST=Verify Fizz reboot after cr50 update. Change-Id: If3207d7284f244ca1adf0d516ef744dbc739a9c1 Signed-off-by: Daisuke Nojiri <dnojiri@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/802632 Reviewed-by: Aaron Durbin <adurbin@chromium.org>
Diffstat (limited to 'include/system.h')
-rw-r--r--include/system.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/system.h b/include/system.h
index f0f934ccf4..a47f8a3af3 100644
--- a/include/system.h
+++ b/include/system.h
@@ -34,8 +34,9 @@
#define RESET_FLAG_RBOX (1 << 16) /* Fixed Reset Functionality */
#define RESET_FLAG_SECURITY (1 << 17) /* Security threat */
/* Per chip implementation to save raw RESET_FLAG_ flags. */
void chip_save_reset_flags(int flags);
+uint32_t chip_read_reset_flags(void);
/* System images */
enum system_image_copy_t {
@@ -34,8 +34,9 @@
#define RESET_FLAG_RBOX (1 << 16) /* Fixed Reset Functionality */
#define RESET_FLAG_SECURITY (1 << 17) /* Security threat */
-/* Per chip implementation to save raw RESET_FLAG_ flags. */
+/* Per chip implementation to save/read raw RESET_FLAG_ flags. */
void chip_save_reset_flags(int flags);